@@ -1,15 +1,17 @@
 package # hide from pause
   MyModuleNoBase;
+use strict;
+use warnings;
 
 use base 'Class::C3::Componentised';
 
-sub message { 
+sub message {
   my $msg = $_[0]->maybe::next::method() || '';
-  
+
   return $msg . ' ' . __PACKAGE__;
 }
 
-sub new { 
+sub new {
   return bless {}, shift;
 }
 
